/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2009 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp09nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp09nid ;

DATA library.&dataset ;
INFILE datafile LRECL=1982;
INPUT
   DISGORGE  1              BUSTEXT $ 2-51           OWNSTEXT $ 52         
   FINSTXT $ 53-88          FINDOTXT $ 89            OFENTXT1 $ 90-119     
   OFENTXT2 $ 120           OFENTXT3 $ 121           PRMONTXT $ 122-138    
   ORDERTXT $ 139-224       TYPEOTTX $ 225-291       CPIDN  292-298        
   PSR  299                 JANDC  300               PLEA  301             
   REASONS  302             INDICT  303              SENTRANS  304         
   WRKSHT  305              INCORPYR  306-309        INCORLOC  310         
   ORGTYPE  311             BUSCLAS  312-315         FTEMNUM  316-319      
   FTEMSIGN  320            SELFREP  321             HSMISCND  322         
   PRCRIME  323             PRCIVIL  324             OWNSTRCT  325         
   FINSTDS  326             FINSTDO  327             OFFENSE1  328-329     
   OFFENSE2  330            OFFENSE3  331            PRIMOFF  332-333      
   NOCOUNTS  334-335        SOURCES  336             OFFLVL  337-338       
   DETBFINE  339            TOLERNCE  340            HISTORY  341          
   VIOLATE  342             OBSTRUCT  343            COMPLY  344           
   ACCEPT  345-346          CCULPSCO  347-348        FCULPSCO  349         
   MINFINML  350-352        MAXFINML  353-355        DISPOSIT  356         
   PROBATN  357-358         COFI  359                PROBMON  360          
   ORDERCE  361             TYPEOTHS  362-363        CRIMPURP  364         
   CANTPAY  365             SMIN1  366-373           SMIN2  374-379        
   SMIN3  380-385           SMIN4  386-391           SMIN5  392            
   SMIN6  393               SMIN7  394               SMIN8  395            
   SMIN9  396               SMIN10  397              SMIN11  398           
   SMIN12  399              SMIN13  400              SMIN14  401           
   SMIN15  402              SMIN16  403              SMIN17  404           
   SMIN18  405              SMIN19  406              SMIN20  407           
   SMIN21  408              SMIN22  409              SMIN23  410           
   SMIN24  411              SMIN25  412              SMIN26  413           
   SMIN27  414              SMIN28  415              SMIN29  416           
   SMIN30  417              SMIN31  418              SMIN32  419           
   SMIN33  420              SMIN34  421              SMAX1  422-430        
   SMAX2  431-438           SMAX3  439-445           SMAX4  446-452        
   SMAX5  453-458           SMAX6  459-464           SMAX7  465-470        
   SMAX8  471-476           SMAX9  477-482           SMAX10  483-488       
   SMAX11  489-494          SMAX12  495-500          SMAX13  501-506       
   SMAX14  507-512          SMAX15  513-518          SMAX16  519-524       
   SMAX17  525-530          SMAX18  531-536          SMAX19  537-542       
   SMAX20  543-548          SMAX21  549-554          SMAX22  555-560       
   SMAX23  561-566          SMAX24  567-572          SMAX25  573-578       
   SMAX26  579-584          SMAX27  585-590          SMAX28  591-596       
   SMAX29  597-602          SMAX30  603-608          SMAX31  609-614       
   SMAX32  615-620          SMAX33  621              SMAX34  622           
   STA1_1 $ 623-634         STA1_2 $ 635-646         STA1_3 $ 647-657      
   STA1_4 $ 658-668         STA1_5 $ 669-679         STA1_6 $ 680-690      
   STA1_7 $ 691-699         STA1_8 $ 700-708         STA1_9 $ 709-717      
   STA1_10 $ 718-726        STA1_11 $ 727-735        STA1_12 $ 736-743     
   STA1_13 $ 744-751        STA1_14 $ 752-760        STA1_15 $ 761-768     
   STA1_16 $ 769-777        STA1_17 $ 778-786        STA1_18 $ 787-794     
   STA1_19 $ 795-803        STA1_20 $ 804-809        STA1_21 $ 810-817     
   STA1_22 $ 818-828        STA1_23 $ 829-837        STA1_24 $ 838-846     
   STA1_25 $ 847-855        STA1_26 $ 856-864        STA1_27 $ 865-873     
   STA1_28 $ 874-882        STA1_29 $ 883-891        STA1_30 $ 892-900     
   STA1_31 $ 901-909        STA1_32 $ 910-918        STA1_33 $ 919-924     
   STA1_34 $ 925-929        STA2_1 $ 930-940         STA2_2 $ 941-949      
   STA2_3 $ 950-958         STA2_4 $ 959-967         STA2_5 $ 968-976      
   STA2_6 $ 977-984         STA2_7 $ 985-992         STA2_8 $ 993-1001     
   STA2_9 $ 1002-1010       STA2_10 $ 1011-1018      STA2_11 $ 1019-1026   
   STA2_12 $ 1027-1035      STA2_13 $ 1036-1044      STA2_14 $ 1045-1052   
   STA2_15 $ 1053-1061      STA2_16 $ 1062-1067      STA2_17 $ 1068-1073   
   STA2_18 $ 1074-1082      STA2_19 $ 1083-1088      STA2_20 $ 1089-1097   
   STA2_21 $ 1098-1106      STA2_22 $ 1107-1115      STA2_23 $ 1116-1124   
   STA2_24 $ 1125-1130      STA2_25 $ 1131-1137      STA2_26 $ 1138-1143   
   STA2_27 $ 1144-1146      STA2_28 $ 1147-1152      STA2_29 $ 1153-1155   
   STA2_30 $ 1156-1158      STA2_31 $ 1159-1164      STA2_32 $ 1165-1170   
   STA2_33 $ 1171-1173      STA2_34 $ 1174           STA3_1 $ 1175-1185    
   STA3_2 $ 1186-1192       STA3_3 $ 1193-1195       STA3_4 $ 1196         
   STA3_5 $ 1197            STA3_6 $ 1198            STA3_7 $ 1199         
   STA3_8 $ 1200            STA3_9 $ 1201            STA3_10 $ 1202        
   STA3_11 $ 1203           STA3_12 $ 1204           STA3_13 $ 1205        
   STA3_14 $ 1206           STA3_15 $ 1207           STA3_16 $ 1208        
   STA3_17 $ 1209           STA3_18 $ 1210           STA3_19 $ 1211        
   STA3_20 $ 1212           STA3_21 $ 1213           STA3_22 $ 1214        
   STA3_23 $ 1215           STA3_24 $ 1216           STA3_25 $ 1217        
   STA3_26 $ 1218           STA3_27 $ 1219           STA3_28 $ 1220        
   STA3_29 $ 1221           STA3_30 $ 1222           STA3_31 $ 1223        
   STA3_32 $ 1224           STA3_33 $ 1225           STA3_34 $ 1226        
   NWSTAT1 $ 1227-1238      NWSTAT2 $ 1239-1249      NWSTAT3 $ 1250-1260   
   NWSTAT4 $ 1261-1269      NWSTAT5 $ 1270-1280      NWSTAT6 $ 1281-1290   
   NWSTAT7 $ 1291-1296      NWSTAT8 $ 1297-1301      NWSTAT9 $ 1302-1308   
   NWSTAT10 $ 1309-1314     NOUSTAT  1315-1316       AMENDYR  1317-1320    
   BASEFINE  1321-1329      CH2APP  1330             CH8FINGD  1331        
   CMSRVORD  1332           COMPLYPR  1333           COSTASSM  1334        
   FINOFFST  1335-1338      FORFEITR  1339-1346      GLFINMAX  1347-1355   
   GLFINMIN  1356-1364      REMEDORD  1365-1367      VICTNOTE  1368        
   BOOKERCD  1369-1370      QUARTER  1371            RETEXT1 $ 1372-1396   
   RETEXT2 $ 1397           RETEXT3 $ 1398           RETEXT4 $ 1399        
   RETEXT5 $ 1400           RETEXT6 $ 1401           RETEXT7 $ 1402        
   RETEXT8 $ 1403           RETEXT9 $ 1404           RETEXT10 $ 1405       
   REAS1  1406-1408         REAS2  1409-1411         REAS3  1412           
   REAS4  1413              REAS5  1414              REAS6  1415           
   REAS7  1416-1418         REAS8  1419              REAS9  1420           
   REAS10  1421             INPLEA1  1422            INPLEA2  1423         
   INPLEA3  1424            INPLEA4  1425            INPLEA5  1426         
   INPLEA6  1427            INPLEA7  1428            INPLEA8  1429         
   INPLEA9  1430            INPLEA10  1431           INPLEA11  1432        
   INPLEA12  1433           INNOPL1  1434            INNOPL2  1435         
   INNOPL3  1436            INNOPL4  1437            INNOPL5  1438         
   INNOPL6  1439            INNOPL7  1440            INNOPL8  1441         
   INNOPL9  1442            INNOPL10  1443           INNOPL11  1444        
   INNOPL12  1445           SENTYR  1446-1449        NOCOMP  1450          
   ADJOFL1  1451-1452       ADJOFL2  1453-1454       ADJOFLHI  1455-1456   
   ADJ_B1  1457-1458        ADJ_B2  1459-1460        ADJ_BHI  1461-1462    
   ADJ_C1  1463-1465        ADJ_C2  1466             ADJ_CHI  1467-1469    
   ADJ_D1  1470-1472        ADJ_D2  1473             ADJ_DHI  1474-1476    
   ADJ_E1  1477             ADJ_E2  1478             ADJ_EHI  1479         
   ADJ_F1  1480             ADJ_F2  1481             ADJ_FHI  1482         
   ADJ_G1  1483             ADJ_G2  1484             ADJ_GHI  1485         
   ADJ_H1  1486             ADJ_H2  1487             ADJ_HHI  1488         
   ADJ_I1  1489             ADJ_I2  1490             ADJ_IHI  1491         
   ADJ_J1  1492             ADJ_J2  1493             ADJ_JHI  1494         
   ADJ_K1  1495             ADJ_K2  1496             ADJ_KHI  1497         
   ADJ_L1  1498             ADJ_L2  1499             ADJ_LHI  1500         
   ADJ_M1  1501             ADJ_M2  1502             ADJ_MHI  1503         
   ADJ_N1  1504             ADJ_N2  1505             ADJ_NHI  1506         
   ADJ_O1  1507             ADJ_O2  1508             ADJ_OHI  1509         
   ADJ_P1  1510             ADJ_P2  1511             ADJ_PHI  1512         
   BASADJ1  1513            BASADJ2  1514            BASADJHI  1515        
   BASE1  1516-1517         BASE2  1518              BASEHI  1519-1520     
   ADJOFR1  1521-1522       ADJOFR2  1523            ADJOFRHI  1524-1525   
   ADJR_B1  1526-1527       ADJR_B2  1528            ADJR_BHI  1529-1530   
   ADJR_C1  1531-1532       ADJR_C2  1533            ADJR_CHI  1534-1535   
   ADJR_D1  1536            ADJR_D2  1537            ADJR_DHI  1538        
   ADJR_E1  1539            ADJR_E2  1540            ADJR_EHI  1541        
   ADJR_F1  1542            ADJR_F2  1543            ADJR_FHI  1544        
   ADJR_G1  1545            ADJR_G2  1546            ADJR_GHI  1547        
   ADJR_H1  1548            ADJR_H2  1549            ADJR_HHI  1550        
   ADJR_I1  1551            ADJR_I2  1552            ADJR_IHI  1553        
   ADJR_J1  1554            ADJR_J2  1555            ADJR_JHI  1556        
   ADJR_K1  1557            ADJR_K2  1558            ADJR_KHI  1559        
   ADJR_L1  1560            ADJR_L2  1561            ADJR_LHI  1562        
   ADJR_M1  1563            ADJR_M2  1564            ADJR_MHI  1565        
   ADJR_N1  1566            ADJR_N2  1567            ADJR_NHI  1568        
   ADJR_O1  1569            ADJR_O2  1570            ADJR_OHI  1571        
   ADJR_P1  1572            ADJR_P2  1573            ADJR_PHI  1574        
   BASADR1  1575            BASADR2  1576            BASADRHI  1577        
   BASER1  1578-1579        BASER2  1580             BASERHI  1581-1582    
   ADJOFS1  1583-1584       ADJOFS2  1585-1586       ADJOFSHI  1587-1588   
   ADJS_B1  1589-1590       ADJS_B2  1591-1592       ADJS_BHI  1593-1594   
   ADJS_C1  1595-1597       ADJS_C2  1598            ADJS_CHI  1599-1601   
   ADJS_D1  1602-1604       ADJS_D2  1605            ADJS_DHI  1606-1608   
   ADJS_E1  1609            ADJS_E2  1610            ADJS_EHI  1611        
   ADJS_F1  1612            ADJS_F2  1613            ADJS_FHI  1614        
   ADJS_G1  1615            ADJS_G2  1616            ADJS_GHI  1617        
   ADJS_H1  1618            ADJS_H2  1619            ADJS_HHI  1620        
   ADJS_I1  1621            ADJS_I2  1622            ADJS_IHI  1623        
   ADJS_J1  1624            ADJS_J2  1625            ADJS_JHI  1626        
   ADJS_K1  1627            ADJS_K2  1628            ADJS_KHI  1629        
   ADJS_L1  1630            ADJS_L2  1631            ADJS_LHI  1632        
   ADJS_M1  1633            ADJS_M2  1634            ADJS_MHI  1635        
   ADJS_N1  1636            ADJS_N2  1637            ADJS_NHI  1638        
   ADJS_O1  1639            ADJS_O2  1640            ADJS_OHI  1641        
   ADJS_P1  1642            ADJS_P2  1643            ADJS_PHI  1644        
   BASADS1  1645            BASADS2  1646            BASADSHI  1647        
   BASES1  1648-1649        BASES2  1650             BASESHI  1651-1652    
   ADJOFC1  1653            ADJOFC2  1654            ADJOFCHI  1655        
   ADJC_B1  1656            ADJC_B2  1657            ADJC_BHI  1658        
   ADJC_C1  1659            ADJC_C2  1660            ADJC_CHI  1661        
   ADJC_D1  1662            ADJC_D2  1663            ADJC_DHI  1664        
   ADJC_E1  1665            ADJC_E2  1666            ADJC_EHI  1667        
   ADJC_F1  1668            ADJC_F2  1669            ADJC_FHI  1670        
   ADJC_G1  1671            ADJC_G2  1672            ADJC_GHI  1673        
   ADJC_H1  1674            ADJC_H2  1675            ADJC_HHI  1676        
   ADJC_I1  1677            ADJC_I2  1678            ADJC_IHI  1679        
   ADJC_J1  1680            ADJC_J2  1681            ADJC_JHI  1682        
   ADJC_K1  1683            ADJC_K2  1684            ADJC_KHI  1685        
   ADJC_L1  1686            ADJC_L2  1687            ADJC_LHI  1688        
   ADJC_M1  1689            ADJC_M2  1690            ADJC_MHI  1691        
   ADJC_N1  1692            ADJC_N2  1693            ADJC_NHI  1694        
   ADJC_O1  1695            ADJC_O2  1696            ADJC_OHI  1697        
   ADJC_P1  1698            ADJC_P2  1699            ADJC_PHI  1700        
   BASADC1  1701            BASADC2  1702            BASADCHI  1703        
   BASEC1  1704             BASEC2  1705             BASECHI  1706         
   ADJL_B1 $ 1707           ADJL_B2 $ 1708           ADJL_BHI $ 1709       
   ADJL_C1 $ 1710-1711      ADJL_C2 $ 1712           ADJL_CHI $ 1713-1714  
   ADJL_D1 $ 1715-1716      ADJL_D2 $ 1717           ADJL_DHI $ 1718-1719  
   ADJL_E1 $ 1720           ADJL_E2 $ 1721           ADJL_EHI $ 1722       
   ADJL_F1 $ 1723           ADJL_F2 $ 1724           ADJL_FHI $ 1725       
   ADJL_G1 $ 1726           ADJL_G2 $ 1727           ADJL_GHI $ 1728       
   ADJL_H1 $ 1729           ADJL_H2 $ 1730           ADJL_HHI $ 1731       
   ADJL_I1 $ 1732           ADJL_I2 $ 1733           ADJL_IHI $ 1734       
   ADJL_J1 $ 1735-1736      ADJL_J2 $ 1737           ADJL_JHI $ 1738-1739  
   ADJL_K1 $ 1740           ADJL_K2 $ 1741           ADJL_KHI $ 1742       
   ADJL_L1 $ 1743           ADJL_L2 $ 1744           ADJL_LHI $ 1745       
   ADJL_M1 $ 1746           ADJL_M2 $ 1747           ADJL_MHI $ 1748       
   ADJL_N1 $ 1749           ADJL_N2 $ 1750           ADJL_NHI $ 1751       
   ADJL_O1 $ 1752           ADJL_O2 $ 1753           ADJL_OHI $ 1754       
   ADJL_P1 $ 1755           ADJL_P2 $ 1756           ADJL_PHI $ 1757       
   BASEL1 $ 1758            BASEL2 $ 1759            BASELHI $ 1760        
   ADRL_B1 $ 1761           ADRL_B2 $ 1762           ADRL_BHI $ 1763       
   ADRL_C1 $ 1764-1765      ADRL_C2 $ 1766           ADRL_CHI $ 1767-1768  
   ADRL_D1 $ 1769           ADRL_D2 $ 1770           ADRL_DHI $ 1771       
   ADRL_E1 $ 1772           ADRL_E2 $ 1773           ADRL_EHI $ 1774       
   ADRL_F1 $ 1775           ADRL_F2 $ 1776           ADRL_FHI $ 1777       
   ADRL_G1 $ 1778           ADRL_G2 $ 1779           ADRL_GHI $ 1780       
   ADRL_H1 $ 1781           ADRL_H2 $ 1782           ADRL_HHI $ 1783       
   ADRL_I1 $ 1784           ADRL_I2 $ 1785           ADRL_IHI $ 1786       
   ADRL_J1 $ 1787-1788      ADRL_J2 $ 1789           ADRL_JHI $ 1790-1791  
   ADRL_K1 $ 1792           ADRL_K2 $ 1793           ADRL_KHI $ 1794       
   ADRL_L1 $ 1795           ADRL_L2 $ 1796           ADRL_LHI $ 1797       
   ADRL_M1 $ 1798           ADRL_M2 $ 1799           ADRL_MHI $ 1800       
   ADRL_N1 $ 1801           ADRL_N2 $ 1802           ADRL_NHI $ 1803       
   ADRL_O1 $ 1804           ADRL_O2 $ 1805           ADRL_OHI $ 1806       
   ADRL_P1 $ 1807           ADRL_P2 $ 1808           ADRL_PHI $ 1809       
   BASERL1 $ 1810           BASERL2 $ 1811           BASERLHI $ 1812       
   ADSL_B1 $ 1813           ADSL_B2 $ 1814           ADSL_BHI $ 1815       
   ADSL_C1 $ 1816-1817      ADSL_C2 $ 1818           ADSL_CHI $ 1819-1820  
   ADSL_D1 $ 1821-1822      ADSL_D2 $ 1823           ADSL_DHI $ 1824-1825  
   ADSL_E1 $ 1826           ADSL_E2 $ 1827           ADSL_EHI $ 1828       
   ADSL_F1 $ 1829           ADSL_F2 $ 1830           ADSL_FHI $ 1831       
   ADSL_G1 $ 1832           ADSL_G2 $ 1833           ADSL_GHI $ 1834       
   ADSL_H1 $ 1835           ADSL_H2 $ 1836           ADSL_HHI $ 1837       
   ADSL_I1 $ 1838           ADSL_I2 $ 1839           ADSL_IHI $ 1840       
   ADSL_J1 $ 1841           ADSL_J2 $ 1842           ADSL_JHI $ 1843       
   ADSL_K1 $ 1844           ADSL_K2 $ 1845           ADSL_KHI $ 1846       
   ADSL_L1 $ 1847           ADSL_L2 $ 1848           ADSL_LHI $ 1849       
   ADSL_M1 $ 1850           ADSL_M2 $ 1851           ADSL_MHI $ 1852       
   ADSL_N1 $ 1853           ADSL_N2 $ 1854           ADSL_NHI $ 1855       
   ADSL_O1 $ 1856           ADSL_O2 $ 1857           ADSL_OHI $ 1858       
   ADSL_P1 $ 1859           ADSL_P2 $ 1860           ADSL_PHI $ 1861       
   BASESL1 $ 1862           BASESL2 $ 1863           BASESLHI $ 1864       
   ADCL_B1 $ 1865           ADCL_B2 $ 1866           ADCL_BHI $ 1867       
   ADCL_C1 $ 1868           ADCL_C2 $ 1869           ADCL_CHI $ 1870       
   ADCL_D1 $ 1871           ADCL_D2 $ 1872           ADCL_DHI $ 1873       
   ADCL_E1 $ 1874           ADCL_E2 $ 1875           ADCL_EHI $ 1876       
   ADCL_F1 $ 1877           ADCL_F2 $ 1878           ADCL_FHI $ 1879       
   ADCL_G1 $ 1880           ADCL_G2 $ 1881           ADCL_GHI $ 1882       
   ADCL_H1 $ 1883           ADCL_H2 $ 1884           ADCL_HHI $ 1885       
   ADCL_I1 $ 1886           ADCL_I2 $ 1887           ADCL_IHI $ 1888       
   ADCL_J1 $ 1889           ADCL_J2 $ 1890           ADCL_JHI $ 1891       
   ADCL_K1 $ 1892           ADCL_K2 $ 1893           ADCL_KHI $ 1894       
   ADCL_L1 $ 1895           ADCL_L2 $ 1896           ADCL_LHI $ 1897       
   ADCL_M1 $ 1898           ADCL_M2 $ 1899           ADCL_MHI $ 1900       
   ADCL_N1 $ 1901           ADCL_N2 $ 1902           ADCL_NHI $ 1903       
   ADCL_O1 $ 1904           ADCL_O2 $ 1905           ADCL_OHI $ 1906       
   ADCL_P1 $ 1907           ADCL_P2 $ 1908           ADCL_PHI $ 1909       
   BASECL1 $ 1910           BASECL2 $ 1911           BASECLHI $ 1912       
   GDLINE1 $ 1913-1917      GDLINE2 $ 1918-1922      GDSTAT1 $ 1923-1927   
   GDSTAT2 $ 1928-1932      GDREF1 $ 1933-1937       GDREF2 $ 1938         
   GDCROS1 $ 1939-1943      GDCROS2 $ 1944           GDLINEHI $ 1945-1949  
   GDSTATHI $ 1950-1954     GDREFHI $ 1955-1959      GDCROSHI $ 1960-1964  
   BOOKER2  1965            BOOKER3  1966            NEWCNVTN  1967        
   RESTCAT  1968            FINECAT  1969            SUSFNCAT  1970        
   LCAT1  1971              LCAT2  1972              LCATHI  1973          
   LCATS1  1974             LCATS2  1975             LCATSHI  1976         
   LCATR1  1977             LCATR2  1978             LCATRHI  1979         
   LCATC1  1980             LCATC2  1981             LCATCHI  1982         
 ;                       

LENGTH
   DISGORGE 3               CPIDN 6                  PSR 3                 
   JANDC 3                  PLEA 3                   REASONS 3             
   INDICT 3                 SENTRANS 3               WRKSHT 3              
   INCORPYR 4               INCORLOC 3               ORGTYPE 3             
   BUSCLAS 4                FTEMNUM 4                FTEMSIGN 3            
   SELFREP 3                HSMISCND 3               PRCRIME 3             
   PRCIVIL 3                OWNSTRCT 3               FINSTDS 3             
   FINSTDO 3                OFFENSE1 3               OFFENSE2 3            
   OFFENSE3 3               PRIMOFF 3                NOCOUNTS 3            
   SOURCES 3                OFFLVL 3                 DETBFINE 3            
   TOLERNCE 3               HISTORY 3                VIOLATE 3             
   OBSTRUCT 3               COMPLY 3                 ACCEPT 3              
   CCULPSCO 3               FCULPSCO 3               DISPOSIT 3            
   PROBATN 3                COFI 3                   PROBMON 3             
   ORDERCE 3                TYPEOTHS 3               CRIMPURP 3            
   CANTPAY 3                SMIN1 6                  SMIN2 6               
   SMIN3 6                  SMIN4 6                  SMIN5 3               
   SMIN6 3                  SMIN7 3                  SMIN8 3               
   SMIN9 3                  SMIN10 3                 SMIN11 3              
   SMIN12 3                 SMIN13 3                 SMIN14 3              
   SMIN15 3                 SMIN16 3                 SMIN17 3              
   SMIN18 3                 SMIN19 3                 SMIN20 3              
   SMIN21 3                 SMIN22 3                 SMIN23 3              
   SMIN24 3                 SMIN25 3                 SMIN26 3              
   SMIN27 3                 SMIN28 3                 SMIN29 3              
   SMIN30 3                 SMIN31 3                 SMIN32 3              
   SMIN33 3                 SMIN34 3                 SMAX1 6               
   SMAX2 6                  SMAX3 6                  SMAX4 6               
   SMAX5 6                  SMAX6 6                  SMAX7 6               
   SMAX8 6                  SMAX9 6                  SMAX10 6              
   SMAX11 6                 SMAX12 6                 SMAX13 6              
   SMAX14 6                 SMAX15 6                 SMAX16 6              
   SMAX17 6                 SMAX18 6                 SMAX19 6              
   SMAX20 6                 SMAX21 6                 SMAX22 6              
   SMAX23 6                 SMAX24 6                 SMAX25 6              
   SMAX26 6                 SMAX27 6                 SMAX28 6              
   SMAX29 6                 SMAX30 6                 SMAX31 6              
   SMAX32 6                 SMAX33 3                 SMAX34 3              
   NOUSTAT 3                AMENDYR 4                BASEFINE 6            
   CH2APP 3                 CH8FINGD 3               CMSRVORD 3            
   COMPLYPR 3               COSTASSM 3               FINOFFST 4            
   FORFEITR 6               GLFINMAX 6               GLFINMIN 6            
   REMEDORD 4               VICTNOTE 3               BOOKERCD 3            
   QUARTER 3                REAS1 4                  REAS2 4               
   REAS3 3                  REAS4 3                  REAS5 3               
   REAS6 3                  REAS7 4                  REAS8 3               
   REAS9 3                  REAS10 3                 INPLEA1 3             
   INPLEA2 3                INPLEA3 3                INPLEA4 3             
   INPLEA5 3                INPLEA6 3                INPLEA7 3             
   INPLEA8 3                INPLEA9 3                INPLEA10 3            
   INPLEA11 3               INPLEA12 3               INNOPL1 3             
   INNOPL2 3                INNOPL3 3                INNOPL4 3             
   INNOPL5 3                INNOPL6 3                INNOPL7 3             
   INNOPL8 3                INNOPL9 3                INNOPL10 3            
   INNOPL11 3               INNOPL12 3               SENTYR 4              
   NOCOMP 3                 ADJOFL1 3                ADJOFL2 3             
   ADJOFLHI 3               ADJ_B1 3                 ADJ_B2 3              
   ADJ_BHI 3                ADJ_C1 3                 ADJ_C2 3              
   ADJ_CHI 3                ADJ_D1 3                 ADJ_D2 3              
   ADJ_DHI 3                ADJ_E1 3                 ADJ_E2 3              
   ADJ_EHI 3                ADJ_F1 3                 ADJ_F2 3              
   ADJ_FHI 3                ADJ_G1 3                 ADJ_G2 3              
   ADJ_GHI 3                ADJ_H1 3                 ADJ_H2 3              
   ADJ_HHI 3                ADJ_I1 3                 ADJ_I2 3              
   ADJ_IHI 3                ADJ_J1 3                 ADJ_J2 3              
   ADJ_JHI 3                ADJ_K1 3                 ADJ_K2 3              
   ADJ_KHI 3                ADJ_L1 3                 ADJ_L2 3              
   ADJ_LHI 3                ADJ_M1 3                 ADJ_M2 3              
   ADJ_MHI 3                ADJ_N1 3                 ADJ_N2 3              
   ADJ_NHI 3                ADJ_O1 3                 ADJ_O2 3              
   ADJ_OHI 3                ADJ_P1 3                 ADJ_P2 3              
   ADJ_PHI 3                BASADJ1 3                BASADJ2 3             
   BASADJHI 3               BASE1 3                  BASE2 3               
   BASEHI 3                 ADJOFR1 3                ADJOFR2 3             
   ADJOFRHI 3               ADJR_B1 3                ADJR_B2 3             
   ADJR_BHI 3               ADJR_C1 3                ADJR_C2 3             
   ADJR_CHI 3               ADJR_D1 3                ADJR_D2 3             
   ADJR_DHI 3               ADJR_E1 3                ADJR_E2 3             
   ADJR_EHI 3               ADJR_F1 3                ADJR_F2 3             
   ADJR_FHI 3               ADJR_G1 3                ADJR_G2 3             
   ADJR_GHI 3               ADJR_H1 3                ADJR_H2 3             
   ADJR_HHI 3               ADJR_I1 3                ADJR_I2 3             
   ADJR_IHI 3               ADJR_J1 3                ADJR_J2 3             
   ADJR_JHI 3               ADJR_K1 3                ADJR_K2 3             
   ADJR_KHI 3               ADJR_L1 3                ADJR_L2 3             
   ADJR_LHI 3               ADJR_M1 3                ADJR_M2 3             
   ADJR_MHI 3               ADJR_N1 3                ADJR_N2 3             
   ADJR_NHI 3               ADJR_O1 3                ADJR_O2 3             
   ADJR_OHI 3               ADJR_P1 3                ADJR_P2 3             
   ADJR_PHI 3               BASADR1 3                BASADR2 3             
   BASADRHI 3               BASER1 3                 BASER2 3              
   BASERHI 3                ADJOFS1 3                ADJOFS2 3             
   ADJOFSHI 3               ADJS_B1 3                ADJS_B2 3             
   ADJS_BHI 3               ADJS_C1 3                ADJS_C2 3             
   ADJS_CHI 3               ADJS_D1 3                ADJS_D2 3             
   ADJS_DHI 3               ADJS_E1 3                ADJS_E2 3             
   ADJS_EHI 3               ADJS_F1 3                ADJS_F2 3             
   ADJS_FHI 3               ADJS_G1 3                ADJS_G2 3             
   ADJS_GHI 3               ADJS_H1 3                ADJS_H2 3             
   ADJS_HHI 3               ADJS_I1 3                ADJS_I2 3             
   ADJS_IHI 3               ADJS_J1 3                ADJS_J2 3             
   ADJS_JHI 3               ADJS_K1 3                ADJS_K2 3             
   ADJS_KHI 3               ADJS_L1 3                ADJS_L2 3             
   ADJS_LHI 3               ADJS_M1 3                ADJS_M2 3             
   ADJS_MHI 3               ADJS_N1 3                ADJS_N2 3             
   ADJS_NHI 3               ADJS_O1 3                ADJS_O2 3             
   ADJS_OHI 3               ADJS_P1 3                ADJS_P2 3             
   ADJS_PHI 3               BASADS1 3                BASADS2 3             
   BASADSHI 3               BASES1 3                 BASES2 3              
   BASESHI 3                ADJOFC1 3                ADJOFC2 3             
   ADJOFCHI 3               ADJC_B1 3                ADJC_B2 3             
   ADJC_BHI 3               ADJC_C1 3                ADJC_C2 3             
   ADJC_CHI 3               ADJC_D1 3                ADJC_D2 3             
   ADJC_DHI 3               ADJC_E1 3                ADJC_E2 3             
   ADJC_EHI 3               ADJC_F1 3                ADJC_F2 3             
   ADJC_FHI 3               ADJC_G1 3                ADJC_G2 3             
   ADJC_GHI 3               ADJC_H1 3                ADJC_H2 3             
   ADJC_HHI 3               ADJC_I1 3                ADJC_I2 3             
   ADJC_IHI 3               ADJC_J1 3                ADJC_J2 3             
   ADJC_JHI 3               ADJC_K1 3                ADJC_K2 3             
   ADJC_KHI 3               ADJC_L1 3                ADJC_L2 3             
   ADJC_LHI 3               ADJC_M1 3                ADJC_M2 3             
   ADJC_MHI 3               ADJC_N1 3                ADJC_N2 3             
   ADJC_NHI 3               ADJC_O1 3                ADJC_O2 3             
   ADJC_OHI 3               ADJC_P1 3                ADJC_P2 3             
   ADJC_PHI 3               BASADC1 3                BASADC2 3             
   BASADCHI 3               BASEC1 3                 BASEC2 3              
   BASECHI 3                BOOKER2 3                BOOKER3 3             
   NEWCNVTN 3               RESTCAT 3                FINECAT 3             
   SUSFNCAT 3               LCAT1 3                  LCAT2 3               
   LCATHI 3                 LCATS1 3                 LCATS2 3              
   LCATSHI 3                LCATR1 3                 LCATR2 3              
   LCATRHI 3                LCATC1 3                 LCATC2 3              
   LCATCHI 3 ;

         

RUN ;
